"use strict";
var ais_factory_1 = require("./ais-factory");
var aivdm_nmea_1 = require("../aivdm/aivdm-nmea");
var aivdm_sentence_1 = require("../aivdm/aivdm-sentence");
var AisManager = (function () {
    function AisManager(decoded, bufferSize, incompleted) {
        this.decoded = decoded;
        this.bufferSize = bufferSize;
        this.incompleted = incompleted;
        this.sentences = [];
    }
    AisManager.prototype.add = function (text) {
        var lines = text.split("\n");
        for (var _i = 0, lines_1 = lines; _i < lines_1.length; _i++) {
            var line = lines_1[_i];
            line.replace(/\r*$/, "");
        }
        for (var _a = 0, lines_2 = lines; _a < lines_2.length; _a++) {
            var line = lines_2[_a];
            var nmea = new aivdm_nmea_1.AivdmNmea(line);
            var targetSentence = null;
            for (var i = 0; i < this.sentences.length; i++) {
                var sentence = this.sentences[i];
                if (sentence.isAddable(nmea)) {
                    targetSentence = this.sentences.splice(i, 1)[0];
                    break;
                }
            }
            if (targetSentence !== null) {
                targetSentence.add(nmea);
            }
            else {
                targetSentence = new aivdm_sentence_1.AivdmSentence(nmea);
            }
            if (targetSentence.isComplete()) {
                var ais = ais_factory_1.AisFactory.create(targetSentence);
                if (this.decoded !== null || this.decoded !== undefined) {
                    this.decoded(ais);
                }
            }
            else {
                this.sentences.push(targetSentence);
                if (this.bufferSize === null || this.bufferSize === undefined) {
                    return;
                }
                if (this.sentences.length <= this.bufferSize) {
                    return;
                }
                if (this.incompleted === null || this.incompleted === undefined) {
                    return;
                }
                var oldIncompletedSentences = this.sentences.splice(0, this.sentences.length - this.bufferSize);
                for (var _b = 0, oldIncompletedSentences_1 = oldIncompletedSentences; _b < oldIncompletedSentences_1.length; _b++) {
                    var sentence = oldIncompletedSentences_1[_b];
                    this.incompleted(sentence);
                }
            }
        }
    };
    return AisManager;
}());
exports.AisManager = AisManager;
//# sourceMappingURL=C:/Users/aroll/Projects/AIS/trunk/ts/ais-js/src/ais/ais-manager.js.map